*** Replication code for Pasricha, Falagiarda, Bijsterbosch and Aizenman (2018) - Section 3: Recent trends in capital controls (Figure 1)

** change to your local directory here:
cd "C:\"

** Upload dataset on capital controls
use "CC200112_unann_quarterly.dta", clear


sort year wb_code
local varlist easingin easingout easingio tighteningin tighteningout tighteningio ///
wgt_easingin wgt_easingout wgt_easingio wgt_tighteningin wgt_tighteningout wgt_tighteningio ///
nkired wgt_nkired nkiinc wgt_nkiinc netnkirestr wgt_netnkirestr ///
hotnkired wgt_hotnkired hotnkiinc wgt_hotnkiinc hotnetnkirestr wgt_hotnetnkirestr ///
hoteasingin hoteasingout hoteasingio hottighteningin hottighteningout hottighteningio ///
wgt_hoteasingin wgt_hoteasingout wgt_hoteasingio wgt_hottighteningin wgt_hottighteningout wgt_hottighteningio ///

foreach x of local varlist {
by year: egen sum_`x' = total(`x')
}

by year: keep if _n==1
keep year sum_*
ren sum_* *

egen allmeasures = rowtotal(easingin easingout easingio tighteningin tighteningout tighteningio), missing
egen wgt_allmeasures = rowtotal(wgt_easingin wgt_easingout wgt_easingio wgt_tighteningin wgt_tighteningout wgt_tighteningio), missing
egen allhotmeasures = rowtotal(hoteasingin hoteasingout hoteasingio hottighteningin hottighteningout hottighteningio), missing
egen wgt_allhotmeasures = rowtotal(wgt_hoteasingin wgt_hoteasingout wgt_hoteasingio wgt_hottighteningin wgt_hottighteningout wgt_hottighteningio), missing

label var  easingout "Outflow Easings"
label var  tighteningout "Outflow Tightenings"
label var  easingin "Inflow Easings"
label var  tighteningin "Inflow Tightenings"
label var  easingio "other easings (not inflow or outflow specific)"
label var  tighteningio "other tightenings (not inflow or outflow specific)"
label var  hoteasingout "non-FDI Outflow Easings"
label var  hottighteningout "non-FDI Outflow Tightenings"
label var  hoteasingin "non-FDI Inflow Easings"
label var  hottighteningin "non-FDI Inflow Tightenings"
label var  hoteasingio "non-FDI other easings (not inflow or outflow specific)"
label var  hottighteningio "non-FDI other tightenings (not inflow or outflow specific)"
label var nkired "NKI Reducing measures"
label var nkiinc "NKI Increasing measures"
label var netnkirestr "net NKI Restricting Measures"
label var hotnkired "non-FDI NKI Reducing measures"
label var hotnkiinc "non-FDI NKI Increasing measures"
label var hotnetnkirestr "non-FDI net NKI Restricting Measures"
label var  wgt_easingout "Weighted, Outflow Easings"
label var  wgt_tighteningout "Weighted, Outflow Tightenings" 
label var  wgt_easingin "Weighted, Inflow Easings" 
label var  wgt_tighteningin "Weighted, Inflow Tightenings" 
label var  wgt_easingio "Weighted, other easings (not inflow or outflow specific)" 
label var  wgt_tighteningio "Weighted, other tightenings (not inflow or outflow specific)" 
label var  wgt_hoteasingout "Weighted, non-FDI Outflow Easings" 
label var  wgt_hottighteningout "Weighted, non-FDI Outflow Tightenings" 
label var  wgt_hoteasingin "Weighted, non-FDI Inflow Easings"
label var  wgt_hottighteningin "Weighted, non-FDI Inflow Tightenings" 
label var  wgt_hoteasingio "Weighted, non-FDI other easings (not inflow or outflow specific)" 
label var  wgt_hottighteningio "Weighted, non-FDI other tightenings (not inflow or outflow specific)" 
label var wgt_nkired "Weighted, NKI Reducing measures" 
label var wgt_nkiinc "Weighted, NKI Increasing measures" 
label var wgt_netnkirestr "Weighted, net NKI Restricting Measures" 
label var wgt_hotnkired "Weighted, non-FDI NKI Reducing measures" 
label var wgt_hotnkiinc "Weighted, non-FDI NKI Increasing measures" 
label var wgt_hotnetnkirestr "Weighted, non-FDI net NKI Restricting Measures"
label var allmeasures "All Measures"
label var wgt_allmeasures "Weighted, All Measures"
label var allhotmeasures "non-FDI Measures"
label var wgt_allhotmeasures "Weighted, non-FDI Measures"

capture drop year1 year2
gen year1=year+0.1
gen year2=year-0.1

** Figure 1
egen sum_all = sum(allmeasures)
egen sum_wgt_all = sum(wgt_allmeasures)
gen allz = allmeasures*100/sum_all 
gen wallz = wgt_allmeasures*100/sum_wgt_all 

egen sum_allhot = sum(allhotmeasures)
egen sum_wgt_allhot = sum(wgt_allhotmeasures)
gen allhotz = allhotmeasures*100/sum_allhot 
gen wallhotz = wgt_allmeasures*100/sum_wgt_allhot 

twoway bar allz year, lwidth(medthick) || line wallz year, legend(off) graphregion(color(white) lcolor(black)) lpattern(dash) lwidth(medthick) ///
xtitle("") ytitle("%")  xlabel(#11) name(all, replace) subtitle("Including FDI-related measures") legend(label(1 "Weak") label(2 "Medium"))

br year allhotz	wallhotz	allz	wallz
